<?php
 
//error_reporting(E_ALL);
//ini_set('display_errors', True);

    class MassPhoto extends Feathers implements Feather {
        public function __init() {
            $this->setField(array("attr" => "title",
                                  "type" => "text",
                                  "label" => __("Title", "text"),
                                  "optional" => true));
            $this->setField(array("attr" => "mass-photo",
                                  "type" => "file",
                                  "multiple" => true,
                                  "label" => __("Photos", "mass-photo"),
                                  "note" => "<small>Hold Shift key to select multiple files. (Max. file size: ".ini_get('upload_max_filesize').", max. files: ".ini_get('max_file_uploads').")</small>"));
            $this->setField(array("attr" => "caption",
                                  "type" => "text_block",
                                  "label" => __("Caption", "photo"),
                                  "optional" => true,
                                  "preview" => true));

            $this->setFilter("title", array("markup_title", "markup_post_title"));
            $this->setFilter("caption", array("markup_text", "markup_post_text"));

            $this->respondTo("delete_post", "delete_file");
            $this->respondTo("filter_post", "filter_post");
            $this->respondTo("post_options", "add_option");
        }

        public function submit() {
            if (!isset($_POST['filenames'])) {
                $filenames = array();
                //if (isset($_FILES['mass-photo']) and $_FILES['mass-photo']['error'] == 0) {
                if (isset($_FILES['mass-photo'])) {
                    $files = $this->emulate_files_var($_FILES['mass-photo']);
                    foreach($files as $image) {
                        array_push($filenames, upload($image, array("jpg", "jpeg", "png", "gif", "bmp")));
                    }
                }
                elseif (!empty($_POST['from_url'])) {
                    $images = $this->parse_image_links($_POST['from_url']);
                    foreach($images as $image) {
                        array_push($filenames, upload_from_url($image, array("jpg", "jpeg", "png", "gif", "bmp")));
                    }
                }
                else
                    error(__("Error"), __("Couldn't upload photos"));
            } else
                $filenames = $_POST['filenames'];
                
            // Prepend scheme if a URL is detected
            if (preg_match('~^(([a-z]|[0-9]|\-)+)\.)+([a-z]){2,6}/~', @$_POST['option']['source']))
            $_POST['option']['source'] = "http://".$_POST['option']['source'];
                
            fallback($_POST['slug'], sanitize($_POST['title']));
            
            if (is_array($filenames))
                $filenames = implode("\n", $filenames);

            return Post::add(array("title" => $_POST['title'],
                                   "filenames" => $filenames,
                                   "caption" => $_POST['caption']),
                             $_POST['slug'],
                             Post::check_url($_POST['slug']));
        }

        public function update($post) {
            if (!isset($_POST['filenames'])) {
                $filenames = array();
                if (isset($_FILES['mass-photo']) and $_FILES['mass-photo']['error'] == 0) {
                    $this->delete_files($post);
                    foreach($_FILES['mass-photo'] as $file) {
                        array_push($filenames, upload($file, array("jpg", "jpeg", "png", "gif", "tiff", "bmp")));
                    }
                } elseif (!empty($_POST['from_url'])) {
                    $this->delete_files($post);
                    foreach($_POST['from_url'] as $image) {
                        array_push($filenames, upload_from_url($image, array("jpg", "jpeg", "png", "gif", "bmp")));
                    }
                } else
                    $filenames = $post->filenames;
            } else {
                $this->delete_files($post);
                $filenames = $_POST['filenames'];
            }
            
            // Prepend scheme if a URL is detected
            if (preg_match('~^((([a-z]|[0-9]|\-)+)\.)+([a-z]){2,6}/~', @$_POST['option']['source']))
            $_POST['option']['source'] = "http://".$_POST['option']['source'];
            
            if (is_array($filenames))
                $filenames = implode("\n", $filenames);
            
            $post->update(array("title" => $_POST['title'],
                                "filenames" => $filenames,
                                "caption" => $_POST['caption']));
        }

        public function title($post) {
            return oneof($post->title, $post->title_from_excerpt());
        }
        public function excerpt($post) {
            return $post->caption;
        }

        public function feed_content($post) {
            $content = "";
            foreach(explode("\n", $post->filenames) as $filename) {
                $content .= self::image_tag($filename, 500, 500);
            }
            return $content."<br /><br />".$post->caption;
        }

        public function delete_files($post) {
            if ($post->feather != "mass-photo") return;
            foreach(explode("\n", $post->filenames) as $filename) {
                unlink(MAIN_DIR.Config::current()->uploads_path.$filename);
            }
        }

        public function filter_post($post) {
            if ($post->feather != "mass-photo") return;
            $images = "";
            foreach(explode("\n", $post->filenames) as $filename) {
                $images .= $this->image_tag($filename);
            }
            $post->images = $images;
        }

        public function image_tag($filename, $max_width = 250, $max_height = null, $more_args = "quality=100") {
            $config = Config::current();
            return '<img src="'.$config->chyrp_url.'/includes/thumb.php?file=..'.$config->uploads_path.urlencode($filename).'&amp;max_width='.$max_width.'&amp;max_height='.$max_height.'&amp;'.$more_args.'" alt="'.$filename.'" class="image mass-image" />';
        }

        public function image_links($post, $max_width = 250, $max_height = null, $more_args = "quality=100") {
            $config = Config::current();
            $tags = "";
            foreach(explode("\n", $post->filenames) as $filename) {
                $alt = $filename;
                $tags .= '<a href="'.$config->chyrp_url.$config->uploads_path.urlencode($filename).'" class="photo-link">'.$this->image_tag($filename, $max_width, $max_height, $more_args).'</a>';
            }
            if (!empty($post->source))
                $tags .= '<br><a href="'.$source.'" class="photo-source-link">'.$alt.'</a>';
            return $tags;
        }

        public function add_option($options, $post = null) {
            if (isset($post) and $post->feather != "mass-photo") return;
            elseif (Route::current()->action == "write_post")
                if (!isset($_GET['feather']) and Config::current()->enabled_feathers[0] != "mass-photo" or
                    isset($_GET['feather']) and $_GET['feather'] != "mass-photo") return;

            $options[] = array("attr" => "option[source]",
                               "label" => __("Source", "mass-photo"),
                               "type" => "text",
                               "value" => oneof(@$post->source, ""));

            $options[] = array("attr" => "from_url",
                               "label" => __("From URL?", "mass-photo"),
                               "type" => "text_block",
                               "note" => "<small>(One direct link to an image per line.)</small>");

            return $options;
        }

        public function parse_image_links($links_list) {
            $image_links_array = preg_split('/\r\n|\r|\n/', $links_list);
            foreach($image_links_array as $key => $string) {
                if (!preg_match("/\.(jpg|jpeg|png|gif|bmp)$/", $string))
                    unset($image_links_array[$key]);
            }
            return $image_links_array;
        }

        public function emulate_files_var($files_var) {
            $files = array();
            foreach($files_var as $name=>$file) {
                if(is_array($file)){
                    $count = count($file);
                        for($i=0; $i < $count; $i++) {
                            $files[$i] = array('name' => $files_var['name'][$i],
                                                      'type' => $files_var['type'][$i],
                                                  'tmp_name' => $files_var['tmp_name'][$i],
                                                     'error' => $files_var['error'][$i],
                                                      'size' => $files_var['size'][$i]);
                        }
                } else {
                  $files = $files_var;
                }
            }
            return $files;
        }

    }
